#include "JQRSObj.h"
#include "JInteger.h"
#include "JIntegerData.h"
#include "JStringData.h"
#include "JIntegerProperty.h"
#include "JIntegerListProperty.h"
#include "JStringProperty.h"
#include "JLinkObj.h"
#include "JBytesData.h"

char* theJQRSObj = JQRSObj().Register();


const char* JQRSObj::className() const { return "JQRSObj";}


JObject* JQRSObj::clone() const { return new JQRSObj(*this);}


// class constructor
JQRSObj::JQRSObj() {
  igm = 1 + 1;
  ogm = 1 + 1;
  enabled = 0;
  grab = 0;
}


void JQRSObj::draw(JGraphics g, int x, int y, int w, int h) {
  JRect rect(x, y, w, h);
  drawText(g, JString("QRS"), rect);
}


boolean JQRSObj::inputAllowed(int n)
{ return !inputSet(n).last();}
JString JQRSObj::inputTag(int n) {
  char* tag[] = {
    "enabled",
    "grab" };
  return( tag[n] );
}


JString JQRSObj::outputTag(int n) {
  char* tag[] = {
    "O2",
    "pulse" };
  return( tag[n] );
}


JFRect JQRSObj::inputArea(int n) {
  return topArea( n, 0, 1 + 1, 0.25 );
}


JFRect JQRSObj::outputArea(int n) {
  return rightArea(n, 0, 1 + 1);
}


int JQRSObj::inputFace(int n) {
  return TOP;
}


int JQRSObj::outputFace(int n) {
  return RIGHT;
}


JFPoint JQRSObj::inputPoint(int n, JLinkObj& link) {
  return topPoint(n, link, 0, 1 + 1 );
}


JFPoint JQRSObj::outputPoint(int n, JLinkObj& link) {
  return rightPoint(n, link, 0, 1 + 1);
}


void JQRSObj::access(int n, JLinkObj& link, const JDataType& data) {
  if ( n == 0 ) {
    INT(data) = O2;
  } else if ( n == 1 ) {
    INT(data) = pulse;
  }
}









//------------------------------------------------------------------------------
extern "C" int StartQRS();
extern "C" int StopQRS();
extern "C" int ReadQRS( int* o2, int*pulse );

void JQRSObj::engine(int n, JLinkObj& link) {
  switch (n) {
  case ENABLED:
    link.access(JIntegerData(enabled));
	if ( enabled ) {
		StartQRS();
	} else {
		StopQRS();
	}
    break;
  case GRAB:
    link.access(JIntegerData(grab));
	if ( grab ) {
		int go2;
		int gpulse;
		if ( ReadQRS( &go2, &gpulse )) {
			O2 = go2;
			broadcast( 0 );
			pulse = gpulse;
			broadcast( 1 );
		}
	}
    break;
  default:
    break;
  }
}


