//************************************************************************
//** 
//** FILE: 
//**	SPIROCRD.H
//**
//** DESCRIPTION:
//**	SpiroCard Driver Include File
//**
//** WARNING!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
//**    This file is shared with:
//**		Windows CE driver
//**		Windows 95 driver
//**		Sensaire 
//**
//** REVISION HISTORY:
//**	21 Nov 01 DDI Changed the driver version to 2.08 (see VxdVersionDescription.txt)
//**	17 Oct 01 DDI Changed the driver version to 2.06 (see VxdVersionDescription.txt)
//**	16 Oct 01 DDI Changed the driver version to 2.05 (see VersionDescription.txt)
//**	10 Oct 01 DDI Changed the driver version to 2.04 (see VersionDescription.txt)
//**	000804 Dong Changed the driver version to 2.02
//**	000228 PAL Changed the driver version to 1.06
//**	000214 PAL Changed the driver version to 1.05
//**	000212 PAL Changed the driver version to 1.04
//**	000117 PAL Added SpiroCard BOM Revision Level
//**	000113 PAL Changed the driver version to 1.03
//**	000110 PAL Added FULL_PRESSURE_BUFFER
//**	990407 PAL Changed the EEPROM rev to 1.01
//**	981204 PAL Changed driver version to 1.02
//**	980628 PAL Added SET_CALIBRATION_VALUE
//**	980423 PAL Added SpiroCard Board Revision Level and SpiroCard
//**			   PIC EEPROM Revision level 
//**	980417 PAL Added WRITE_SPIROCARD_REG & defines for sleep/awake
//**	980320 PAL Added Oximetry control
//**	980310 PAL Added DISABLE_INTERRUPTS
//**	980217 PAL Added PRESSURE_BUFFER
//**	980205 PAL Added ENABLE_INTERRUPTS
//**	980112 PAL Added READ_SPIROCARD_REG
//**	980106 PAL Added MAX_SAMPLES
//**		 	   Added results scaling factors
//**	971229 PAL Added RAW_AD_VALUES define
//**	970908 PAL Created
//**
//************************************************************************

#ifndef _SPIROCRD_H
#define _SPIROCRD_H

// Current BOM revision level
#define SPIROCARD_BOM_REV		(0x0214)	// Revision = 2.2
#define SPIROCARD_BOM_REV_2_2	(0x0214)	// Revision = 2.2
// Current Driver revision level
#define SPIROCARD_DRIVER_VER    (0x0208)        // Version = 2.08
// Current PCB revision level
#define SPIROCARD_PCB_REV		(0x4103)	// Revision = A.3
// Current PIC EEPROM revision level
#define SPIROCARD_EEPROM_REV	(0x0101)	// Revison = 1.01

// MAX_SAMPLES = MAXIMUM NUMBER OF SAMPLES RETURNED
// FROM FLOW_BUFFER OR VOLUME_BUFFER, FLOW_VOLUME_SAMPLES
// CAN RETURN (2 * MAX_SAMPLES) SAMPLES
#define SAMPLES_PER_SEC			(100)
#define MAX_SAMPLES				(6000)
#define NUM_SAMPLES				(6000)
#define FLOW_SCALING_FACTOR		(1000)
#define VOL_SCALING_FACTOR		(1000)
#define PRESS_SCALING_FACTOR	(1000)
#define FVC_RESULTS_FACTOR		(1000)
#define MVV_RESULTS_FACTOR		(1000)
#define SVC_RESULTS_FACTOR		(1000)

#define HALF_SECOND				((SAMPLES_PER_SEC)/2)
#define ONE_SECOND				(SAMPLES_PER_SEC)
#define THREE_SECOND			((SAMPLES_PER_SEC)*3)

#define RESET_SPIROCARD			(1)
#define VERSION					(2)
#define SET_MOUTHPIECE			(3)
#define START_ZERO				(4)
#define ZERO_DONE				(5)
#define START_FVC				(6)
#define START_MVV				(7)
#define	START_SVC				(8)
#define FLOW_VOLUME_SAMPLES		(9)
#define FLOW_BUFFER				(10)
#define VOLUME_BUFFER			(11)
#define FVC_RESULTS				(12)
#define MVV_RESULTS				(13)
#define SVC_RESULTS				(14)
#define RAW_AD_VALUES			(15)
#define READ_SPIROCARD_REG		(16)
#define ENABLE_INTERRUPTS		(17)
#define PRESSURE_BUFFER			(18)
#define DISABLE_INTERRUPTS		(19)
#define READ_CALIBRATION_VALUE	(20)
#define WRITE_CALIBRATION_VALUE	(21)
#define WRITE_SPIROCARD_REG		(22)
#define SPIROCARD_SLEEP			(23)
#define SPIROCARD_AWAKE			(24)
#define WRITE_PCB_REV			(25)
#define READ_PCB_REV			(26)
#define WRITE_EEPROM_REV		(27)
#define READ_EEPROM_REV			(28)
#define START_TEST_MODE			(29)
#define PRESSURE_VALUES			(30)
#define SET_CALIBRATION_VALUE	(31)
#define CONFIGURE_IO			(32)
#define AD_BUFFER				(33)
#define TEST_STATUS				(34)
#define WRITE_SERIAL_NUM		(35)
#define READ_SERIAL_NUM			(36)
#define BTPS_CORRECTION			(37)
#if 0
#define CALCULATE_FVC_RESULTS	(38)
#endif
#define END_TEST				(39)
#define FULL_PRESSURE_BUFFER	(40)
#define WRITE_BOM_REV			(41)
#define READ_BOM_REV			(42)
#define ABSOLUTE_AIR_PRESSURE	(43)
#define ELEVATION				(44)
#define ELEVATION_AND_RELATIVE_AIR_PRESSURE	(45)
#define WRITE_PC_CARD_TYPE		(46) //Dong add
#define READ_PC_CARD_TYPE		(47) //Dong add

#define FVC_TEST				(0)
#define SVC_TEST				(1)
#define MVV_TEST				(2)

#define TEST_NOT_DONE			(0)
#define TEST_DONE				(1)
#define TEST_TIMEOUT			(2)

#define ZERO_COMPLETE			(100)
#define ZERO_NOT_DONE			(101)
#define ZERO_NOT_STARTED		(102)
#define ZERO_TIMEOUT			(103)

#define NO_ERR					(0)
#define MVV_SHORT_ERR			(-100)

#define BTPS_DISABLED			(0)
#define BTPS_ENABLED			(1)

//****** OXICARD CONTROL **********************
#define RESET_OXICARD		(201)
#define OXI_SPO2			(202)
#define OXI_PULSE			(203)
#define OXI_VERSION			(205)
#define OXI_SPO2PULSEBUFFER	(204)
#define PLETH_BUFFER		(206)
#define OXI_STATUS			(207)
#define OXI_POWER_ON		(208)
#define SET_OXIMETER_RESET	(209)
#define CLEAR_OXIMETER_RESET (210)
#define OXIOCARD_DRIVER_VER	(0x0100) //1.00
//Dong add
#define MAX_HEART_RATE (301)//RATE (4)  //card is reading at four times/second
//Dong end
#define Spo2PulseBuffer_Size (1800)
//*********************************************


//*********PC Card Type**********************
#define SpiroCard_Type		(0)
#define OxiCard_Type		(1)
#define SpiroxCard_Type		(2)
#define No_Card				(127)
//*********************************************
//****** SPIROCARD REGISTER DEFINES ***********
#define SPIROCARD_PRESS_LSB_REG_OFF		(0x00)	// Least Significant Byte of Pressure reading Register Offset
#define SPIROCARD_PRESS_MSB_REG_OFF		(0x02)	// Most Significant Byte of Pressure reading Register Offset
#define SPIROCARD_INT_ACK_REG_OFF		(0x00)	// Interrupt Acknowledge Register Offset
#define SPIROCARD_CONTROL_REG_OFF		(0x02)	// SpiroCard Control Register Offset
#define SPIROCARD_SLEEP_MODE			(0x01)	// Place SpiroCard into SLEEP mode

#define FEMALE				(0)
#define MALE				(1)

#define ASIAN				(0)
#define BLACK				(1)
#define CAUCASIAN			(2)
#define HISPANIC			(3)

#define ENGLISH				(0)
#define METRIC				(1)
#endif // _SPIROCRD_H
